==> vhffs-4.2.1.tar.bz2: vhffs-4.2.1/vhffs-api/src/Vhffs/Robots/Cvs.pm <==
#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

package Vhffs::Robots::Cvs;

use strict;
use utf8;

use Vhffs::Services::Cvs;
use Vhffs::Constants;
use Vhffs::Functions;

sub create_cvs
{
	my $cvs = shift;
	return -1 unless defined $cvs;
	return -1 if $cvs->get_status != Vhffs::Constants::WAITING_FOR_CREATION;

	my $dir = $cvs->get_dir;

	if( -e $dir ) {
		$cvs->set_status( Vhffs::Constants::CREATING_ERROR );
		$cvs->commit();
		$cvs->add_history('Error, directory of this cvs repository already exists! Administrators must fix the problem.');
		return -1;
	}

	Vhffs::Functions::create_dir( $dir );
	Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
	Vhffs::Functions::change_owner_recur( $dir , $cvs->get_owner_uid , $cvs->get_owner_gid );
	$cvs->add_history('Ok, robots find the empty directory and will create cvs repository');

	system('cvs -d '.$dir.' init');

	unless( -d $dir.'/CVSROOT' ) {
		$cvs->set_status( Vhffs::Constants::CREATING_ERROR );
		$cvs->commit();
		$cvs->add_history('Error, nothing was created after calling the cvs binary, something is wrong.');
		return -1;
	}

	Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
	Vhffs::Functions::change_owner_recur( $dir , $cvs->get_owner_uid , $cvs->get_owner_gid );

	$cvs->add_history('The Robots created the subversion repository');
	$cvs->set_status( Vhffs::Constants::ACTIVATED );
	$cvs->commit;

	return 0;
}


sub delete_cvs
{
	use File::Path;
	use File::Basename;
	my $cvs = shift;
	return -1 unless defined $cvs;

	my $dir = $cvs->get_dir;
	File::Path::rmtree($dir) if(-d $dir);
	# Remove parent dir if empty (i.e. this group has no move CVSes).
	my $groupdir = dirname($dir);
	rmdir $groupdir;

	return 0;
}


1;

==> vhffs-4.3.1.tar.bz2: vhffs-4.3.1/vhffs-api/src/Vhffs/Robots/Cvs.pm <==
#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

package Vhffs::Robots::Cvs;

use strict;
use utf8;

use Vhffs::Services::Cvs;
use Vhffs::Constants;
use Vhffs::Functions;

sub create_cvs
{
	my $cvs = shift;
	return -1 unless defined $cvs;
	return -1 if $cvs->get_status != Vhffs::Constants::WAITING_FOR_CREATION;

	my $dir = $cvs->get_dir;

	if( -e $dir ) {
		$cvs->set_status( Vhffs::Constants::CREATING_ERROR );
		$cvs->commit();
		$cvs->add_history('Error, directory of this cvs repository already exists! Administrators must fix the problem.');
		return -1;
	}

	Vhffs::Functions::create_dir( $dir );
	Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
	Vhffs::Functions::change_owner_recur( $dir , $cvs->get_owner_uid , $cvs->get_owner_gid );
	$cvs->add_history('Ok, robots find the empty directory and will create cvs repository');

	system('cvs -d '.$dir.' init');

	unless( -d $dir.'/CVSROOT' ) {
		$cvs->set_status( Vhffs::Constants::CREATING_ERROR );
		$cvs->commit();
		$cvs->add_history('Error, nothing was created after calling the cvs binary, something is wrong.');
		return -1;
	}

	Vhffs::Functions::chmod_recur( $dir , 0664 , 02775 );
	Vhffs::Functions::change_owner_recur( $dir , $cvs->get_owner_uid , $cvs->get_owner_gid );

	$cvs->add_history('The Robots created the cvs repository');
	$cvs->set_status( Vhffs::Constants::ACTIVATED );
	$cvs->commit;

	return 0;
}


sub delete_cvs
{
	use File::Path;
	use File::Basename;
	my $cvs = shift;
	return -1 unless defined $cvs;

	my $dir = $cvs->get_dir;
	File::Path::rmtree($dir) if(-d $dir);
	# Remove parent dir if empty (i.e. this group has no move CVSes).
	my $groupdir = dirname($dir);
	rmdir $groupdir;

	return 0;
}


1;
